| mboot | R Documentation |
A function to take an influence function and use the multiplier bootstrap to compute standard errors and critical values for uniform confidence bands.
mboot(inf.func, DIDparams, pl = FALSE, cores = 1, return_V = TRUE)
inf.func |
an influence function |
DIDparams |
DIDparams object |
pl |
whether or not to use parallel processing in the multiplier bootstrap, default=FALSE |
cores |
the number of cores to use with parallel processing, default=1 |
return_V |
whether to compute and return the bootstrap variance
matrix |
list with elements
bres |
results from each bootstrap iteration |
V |
variance matrix ( |
se |
standard errors |
crit.val |
a critical value for computing uniform confidence bands |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.