run_att_gt_estimation: Run ATT estimation for a given group-time pair

View source: R/compute.att_gt2.R

run_att_gt_estimationR Documentation

Run ATT estimation for a given group-time pair

Description

run_att_gt_estimation does the main work for computing multiperiod group-time average treatment effects

Usage

run_att_gt_estimation(g, t, dp2)

Arguments

g

group of interest (treated group at time t)

t

time period

dp2

A DIDparams object v2.0

Value

a list with the gt cell and the results after performing estimation


did documentation built on June 13, 2026, 5:07 p.m.