print a summary of an AGGTE object
# S3 method for AGGTE
summary(object, type = c("dynamic", "selective",
"calendar", "dynsel"), e1 = 1, ...)an AGGTE object
which type of summary to print, options are "dynamic", "selective", "calendar", and "dynsel"
if the type is "dynsel", this is the number of post-treatment periods required in order for a group to be used to construct aggregated parameters with selective treatment timing and dynamic effects; otherwise not used
other variables