multi-period object
MP(group, t, att, V, c, inffunc, n = NULL, W = NULL, Wpval = NULL,
aggte = NULL)which group (defined by period first treated) an group-time average treatment effect is for
which time period a group-time average treatment effect is for
the group-average treatment effect for group group and time period t
the variance matrix for group-time average treatment effects
critical value if one is obtaining uniform confidence bands
the influence function for estimating group-time average treatment effects
the number of observations
the Wald statistic for pre-testing the common trends assumption
the p-value of the Wald statistic for pre-testing the common trends assumption
an aggregate treatment effects object
MP object