Learn R Programming

did (version 1.2.2)

MP.TEST: MP.TEST

Description

MP.TEST objects

Usage

MP.TEST(CvM, CvMb, CvMcval, CvMpval, KS, KSb, KScval, KSpval, clustervars,
  xformla)

Arguments

CvM

Cramer von Mises test statistic

CvMb

a vector of boostrapped Cramer von Mises test statistics

CvMcval

CvM critical value

CvMpval

p-value for CvM test

KS

Kolmogorov-Smirnov test statistic

KSb

a vector of boostrapped KS test statistics

KScval

KS critical value

KSpval

p-value for KS test

clustervars

vector of which variables were clustered on for the test

xformla

formla for the X variables used in the test