MP.TEST objects
MP.TEST(CvM, CvMb, CvMcval, CvMpval, KS, KSb, KScval, KSpval, clustervars,
xformla)Cramer von Mises test statistic
a vector of boostrapped Cramer von Mises test statistics
CvM critical value
p-value for CvM test
Kolmogorov-Smirnov test statistic
a vector of boostrapped KS test statistics
KS critical value
p-value for KS test
vector of which variables were clustered on for the test
formla for the X variables used in the test