A function to take an influence function and use the multiplier bootstrap to compute standard errors and critical values for uniform confidence bands.
Arguments
- inf.func
an influence function
- DIDparams
DIDparams object
- pl
whether or not to use parallel processing in the multiplier bootstrap, default=FALSE
- cores
the number of cores to use with parallel processing, default=1
- return_V
whether to compute and return the bootstrap variance matrix
V. Default isTRUE. Internal callers that only consumebres,se, orcrit.valset this toFALSEto skip the computation (it is the only O(biters x k^2) step in the function).